@@ -41,8 +41,8 @@ def _load_configuration(paths, filename='.ethz_iam_webservice'):
     return admin_accounts
 
 
-def login(admin_username=None, admin_password=None):
-    hostname = "https://iam.passwort.ethz.ch"
+def login(admin_username=None, admin_password=None, hostname="https://iam.passwort.ethz.ch"):
+    hostname = hostname
     endpoint_base = "/iam-ws-legacy"
 
     config_path = os.path.join(
@@ -91,7 +91,7 @@ def get_username_password(ctx):
 def person(ctx, person, info):
     get_username_password(ctx)
 
-    e = login(ctx.obj['username'], ctx.obj['password'])
+    e = login(ctx.obj['username'], ctx.obj['password'], ctx.obj['hostname'])
     person = e.get_person(person)
 
     print(json.dumps(person.data, indent=4, sort_keys=True))
@@ -109,29 +109,29 @@ def person(ctx, person, info):
               )
 @click.option('-g', '--grant-service',
               multiple=True,
-              help='grant a service to this user'
+              help='grant a service to this user, e.g. AD, LDAPS, VPN. Use this option for every service you want to grant'
               )
 @click.option('-r', '--revoke-service',
               multiple=True,
-              help='revoke a service from this user'
+              help='revoke a service from this user, e.g. AD, LDAPS, VPN. Use this option for every service you want to revoke'
               )
 @click.option('--set-password',
               is_flag=True,
-              )
-@click.option('-sp', '--service-password',
-              help='set a password for the given service. Use the --service option to specify the service.',
+              help='set the password for that user. Use -s to specify for which service(s)',
               )
 @ click.option('-s', '--service',
                multiple=True,
-               help='specify the service you want to set the service for',
+               help='specify the service you want to set the password for',
                )
+@click.option('-sp', '--service-password',
+              help='set a password for the given service. Use the --service option to specify the service.',
+              )
 @ click.pass_context
 def user(ctx, user, delete, info, grant_service=None, revoke_service=None, set_password=None, service_password=None, service=None):
     get_username_password(ctx)
-    e = login(ctx.obj['username'], ctx.obj['password'])
+    e = login(ctx.obj['username'], ctx.obj['password'], ctx.obj['hostname'])
     user = e.get_user(user)
 
-
     if delete:
         click.confirm(
             'Do you really want to delete this user?', abort=True)
@@ -154,7 +154,8 @@ def user(ctx, user, delete, info, grant_service=None, revoke_service=None, set_p
             for s in service:
                 try:
                     user.set_password(
-                        password=service_password, service_name=s
+                        password=service_password,
+                        service_name=s
                     )
                     print(f"successfully set password for service {s}")
                 except ValueError as err:
@@ -208,7 +209,7 @@ def group(ctx, group, delete, members, info, add=None, remove=None):
 
     get_username_password(ctx)
 
-    e = login(ctx.obj['username'], ctx.obj['password'])
+    e = login(ctx.obj['username'], ctx.obj['password'],ctx.obj['hostname'])
     group = e.get_group(group)
 
     if add:
@@ -239,15 +240,17 @@ def group(ctx, group, delete, members, info, add=None, remove=None):
 @ click.option('--password',
                help='password of your ETHZ IAM admin account (if not provided, it will be prompted)')
 @ click.option('-h', '--host',
-               default="https://iam.passwort.ethz.ch",
-               help="default: https://iam.passwort.ethz.ch"
+               default="iam.passwort.ethz.ch",
+               help="default: iam.passwort.ethz.ch"
                )
 @ click.pass_context
 def cli(ctx, host, username, password=None):
     """ETHZ IAM command-line tool.
     """
     ctx.ensure_object(dict)
-    ctx.obj['host'] = host
+    if not host.startswith('https://'):
+        host = 'https://' + str(host)
+    ctx.obj['hostname'] = host
     ctx.obj['username'] = username
     ctx.obj['password'] = password
 
