@@ -8,6 +8,10 @@ service_map = {
     "LDAP": "LDAP",
     "LDAPS": "LDAP",
     "MAILBOX": "Mailbox",
+    "AD": "AD",
+    "ACTIVE DIRECTORY": "AD",
+    "VPN": "WLAN_VPN",
+    "WLAN_VPN": "WLAN_VPN",
 }
 
 
@@ -118,4 +122,4 @@ class User():
                 )
         else:
             data = json.loads(resp.content.decode())
-            raise ValueError(data['message'])
+            raise ValueError(f"Error: could not set the password for user {self.username} and service {service_name}.\nMessage: {data['message']}")
